!`Abinde.png`_
Abinde
======

!`size <https://img.shields.io/github/languages/code-size/desvasicek/Abinde>`_

!`issues open <https://img.shields.io/github/issues/desvasicek/Abinde>`_

!`issues closed <https://img.shields.io/github/issues-closed/desvasicek/Abinde>`_

!`downloads <https://img.shields.io/pypi/dd/Abinde>`_

!`stars <https://img.shields.io/github/stars/desvasicek/Abinde>`_

!`forks <https://img.shields.io/github/forks/desvasicek/Abinde>`_

!`watchers <https://img.shields.io/github/watchers/desvasicek/Abinde>`_

!`language <https://img.shields.io/github/languages/top/desvasicek/Abinde>`_

!`license <https://img.shields.io/github/license/desvasicek/Abinde>`_

!`status <https://img.shields.io/pypi/status/Abinde>`_

!`format <https://img.shields.io/pypi/format/Abinde>`_

!`python <https://img.shields.io/pypi/pyversions/Abinde>`_

!`version <https://img.shields.io/pypi/v/Abinde>`_

!`checks <https://img.shields.io/github/checks-status/desvasicek/Abinde/main>`_

!`good first issue <https://img.shields.io/github/labels/desvasicek/Abinde/good%20first%20issue?color=yellow>`_

!`milestones <https://img.shields.io/github/milestones/all/desvasicek/Abinde>`_

Abinde is a python module for pygame.

Advantages
============

- Easy to use
- Lightweight

Requirements
==============

- **pygame** for module.
- **python** for running module.
- **PIL** for image support

Tested on
===========

| Raspberry Pi OS | Debian Linux    | Mac             |

|-----------------|-----------------|-----------------|

| Stable (v1.9.1) | Stable (v1.9)   | Stable (v1.1)    |

Please Note
=============

To use this module, you will need at least some experience with coding python.

How hard is it to create a module?
====================================

It is **really hard**, especially building, which takes **so long**! 
